@@ -31,7 +31,7 @@ fn display_usage(programe_name:String) {
     println!("Usage:");
     println!("{} -f input file [-a][-b][-B][-c config file][-d fontsize][-D fontsize][-e][-E][-F format][-g input file][-G #][-h]\
     [-H height][-i][-I][-J][-l factor][-L][-m][-o output file][-O][-p][-r ratio][-s][-S]\
-    [-t threshold][-T #][-u threshold][-U #][-v][-W width]",programe_name);
+    [-t threshold][-T #][-u threshold][-U #][-v][-W width][-x][-X]",programe_name);
     println!();
     println!("Get help:");
     println!("{} -h ",programe_name);
@@ -48,7 +48,7 @@ fn display_help(programe_name:String) {
     println!("Usage:");
     println!("{} -f input file [-a][-b][-B][-c config file][-d fontsize][-D fontsize][-e][-E][-F format][-g input file][-G #][-h]\
     [-H height][-i][-I][-J][-l factor][-L][-m][-o output file][-O][-p][-r ratio][-s][-S]\
-    [-t threshold][-T #][-u threshold][-U #][-v][-W width]",programe_name);
+    [-t threshold][-T #][-u threshold][-U #][-v][-W width]|-x][-X]",programe_name);
     println!("    -a : output the redundant transfers analysis");
     println!("    -b : open svg in browser");
     println!("    -B : with option -l, display branch length");
@@ -85,6 +85,8 @@ fn display_help(programe_name:String) {
     println!("    -U <n> : same as -T with -t, but for -u");
     println!("    -v : verbose");
     println!("    -W width : multiply the tree width by factor 'width'");
+    println!("    -x : tidy mode (non-layered tidy tree layout)");
+    println!("    -X : tidy mode, avoiding leave names superposition");
     println!("");
     println!("    Note on -b option : you must set a browser as default application for opening \
     svg file");
@@ -93,6 +95,10 @@ fn display_help(programe_name:String) {
     println!("    For example you may input a gene-symbiote recphyloxml file  with -g and symbiote-host recphyloxml file with -f");
     println!("    The -t/-u options are not totally implemented for the 3-levels reconciliation svg output files.");
     println!("");
+    println!("    Note on -x/-X options : the non-layered tidy tree layout is described in :");
+    println!("                            'van der Ploeg, A. 2014. Drawing non-layered tidy trees in linear time.");
+    println!("                            Software: Practice and Experience, 44(12): 1467–1484.'");
+    println!("");
     println!("Input format is guessed according to the file name extension:");
     println!(".phyloxml    => phyloXML");
     println!(".xml         => recPhyloxml");
@@ -118,6 +124,9 @@ fn display_help(programe_name:String) {
     -g recphylo_examples/test2/gene_parasite_page2.recphylo  -b  ", programe_name);
     println!("{} -f recphylo_examples/test1_mult_parasite/rechp_dtl.recphyloxml \
      -g recphylo_examples/test1_mult_parasite/recgs_mult_host_dtl.recphyloxml -b", programe_name);
+    println!("{} -f newick_examples/virus.nhx -l 4 -b", programe_name);
+    println!("{} -f newick_examples/virus.nhx -l 4 -x -b", programe_name);
+    println!("{} -f newick_examples/virus.nhx -l 4 -X -b", programe_name);
     process::exit(1);
 }
 /// enum of the possible input file Formats
@@ -144,7 +153,7 @@ fn main()  {
     if args.len() == 1 {
         display_usage(args[0].to_string());
     }
-    let mut opts = getopt::Parser::new(&args, "ac:bBd:D:eEf:F:g:G:hH:iIJl:Lmo:Opr:sSt:T:u:U:vW:");
+    let mut opts = getopt::Parser::new(&args, "ac:bBd:D:eEf:F:g:G:hH:iIJl:Lmo:Opr:sSt:T:u:U:vW:xX");
     let mut infile_sh = String::new(); // symbiote host file
     let mut infile_gs = String::new(); // gene symbiote file
     let mut outfile = String::from("thirdkind.svg");
@@ -320,6 +329,11 @@ fn main()  {
                             },
                         };
                     },
+                    Opt('x', None) =>  options.tidy = true,
+                    Opt('X', None) =>  {
+                        options.tidy = true;
+                        options.tidy_leaves_check = true;
+                        },
                     _ => unreachable!(),
                 }
             }
